package uy.edu.fing.tse.central.business.common;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Map;
import java.util.Properties;

public enum Propiedades {

    URI("uy.edu.fing.tse.business.rabbit.uri", ""),
    HOST("uy.edu.fing.tse.business.rabbit.host", ""),
    PORT("uy.edu.fing.tse.business.rabbit.port", "5672"),
    VHOST("uy.edu.fing.tse.business.rabbit.vhost", ""),
    USERNAME("uy.edu.fing.tse.business.rabbit.username", ""),
    PASSWORD("uy.edu.fing.tse.business.rabbit.password", "");

    private final String key;
    private final String defaultValue;

    Propiedades(String key, String defaultValue) {
        this.key = key;
        this.defaultValue = defaultValue;
    }

    public String getKey() {
        return key;
    }

    public String getDefaultValue() {
        return defaultValue;
    }

    public String getValue() {
        return System.getProperty(key);
    }

    public Integer getIntValue() {
        return Integer.valueOf(System.getProperty(key));
    }

    public Boolean getBoolValue() {
        return Boolean.valueOf(System.getProperty(key));
    }

    static {
        //Agrego valores por defecto
        for (Propiedades value : Propiedades.values()) {
            System.setProperty(value.key, value.defaultValue);
        }
        //Cargo los valores del archivo de configuracion
        final var inputStream = Propiedades.class.getClassLoader().getResourceAsStream("central.properties");
        load(inputStream);
    }

    public static void load(final File propFile) {
        try (FileInputStream is = new FileInputStream(propFile)) {
            load(is);
        } catch (IOException ex) {
            throw new RuntimeException("Error leyendo el archivo de propiedades", ex);
        }
    }

    public static void load(final InputStream is) {
        try {
            Properties p = new Properties();
            p.load(is);

            for (Map.Entry<Object, Object> entry : p.entrySet()) {
                System.setProperty(entry.getKey().toString(), entry.getValue().toString());
            }

        } catch (IOException ex) {
            throw new RuntimeException("Error leyendo el archivo de propiedades", ex);
        }
    }
}
