package uy.edu.fing.tse.central.business.mq;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.rabbitmq.client.Channel;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.annotation.PostConstruct;
import java.io.IOException;
import java.util.concurrent.TimeoutException;

//@Stateless
public class MessageProducer {

    private static final Logger LOG = LoggerFactory.getLogger(MessageProducer.class);

    private Channel channel;

    @PostConstruct
    public void init() {
        try {
            channel = RabbitConfig.channel();
        } catch (IOException | TimeoutException e) {
            LOG.error("Error: ", e);
            throw new RuntimeException("Error al construir la coneccion con MQ", e);
        }
    }

    public void send(final Object message, final Queue queue) throws IOException {
        final String body = new ObjectMapper().writeValueAsString(message);
        send(body, queue);
    }

    public void send(final String message, final Queue queue) throws IOException {
        channel.basicPublish("", queue.name, null, message.getBytes());
    }
}
